function  [varargout] = mget_ei(run_numbers,varargin)
% mget_ei(run_numbers)
% mget_ei(run_numbers,ei_guesses)
% ei=mget_ei(run_numbers,ei_guesses)
% [ei,properties]=mget_ei(run_numbers,ei_guesses)
%
% ei_guesses must be a numerical array equal to the number of run_numbers,
% containing the starting ei for get_ei to use in its calculation
%
% properties is an optional output containing all the peripheral output
% from the get_ei command ie peak position, area etc...
%
% run numbers can be defnied in the following ways:
% 1) a numerical array of numbers -> [12345  45673 34436] or a single
% numeric
% 2) an array of strings -> char('12345' '45673' '34436') or a single
% string
% 3) a cell array of strings -> {'12345' '45673' '34436'}
% 4) a cell array of numerics -> {12345  45673 34436}
% 5) or a path to a particular raw file -> 'C:\data\MAR11060.RAW' or a cell
% array of paths
%
%
% See also get_ei
[files,num]=make_path_from_par({run_numbers});
guesses=false;
if nargin>1
    guesses=true;
    if size(varargin{1})~= num
        error('number of ei guesses not equal to number of runs')
    end
end

a=zeros(num,1);
b=zeros(num,6);
for i=1:num
    if guesses
        [a(i),b(i,:)]=get_ei(files{i},varargin{1}(i));
    else
        [a(i),b(i,:)]=get_ei(files{i});
    end
end
varargout(1)={a};
varargout(2)={b};
